@@ -11,7 +11,10 @@ import typing_extensions
 import aws_cdk.core._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-cassandra", "1.98.0", __name__[0:-6], "aws-cassandra@1.98.0.jsii.tgz"
+    "@aws-cdk/aws-cassandra",
+    "1.100.0",
+    __name__[0:-6],
+    "aws-cassandra@1.100.0.jsii.tgz",
 )
 
 __all__ = [
